/**
 *  Copyright (c) 2008...2012 Ekkehard Gentz (Rosenheim, Germany) and others.
 *  All rights reserved. This program and the accompanying materials
 *  are made available under the terms of the Eclipse Public License v1.0
 *  which accompanies this distribution, and is available at
 *  http://www.eclipse.org/legal/epl-v10.html
 *  
 *  Contributors:
 *          Ekkehard Gentz     - initial contribution 
 *     
 *   more info: see folder [project]/copyright
 */

package org.appbus.bb.app.hellologging4bb;

import java.util.Hashtable;

import net.rim.device.api.ui.Field;
import net.rim.device.api.ui.FieldChangeListener;
import net.rim.device.api.ui.UiApplication;
import net.rim.device.api.ui.component.ButtonField;
import net.rim.device.api.ui.container.MainScreen;
import net.rim.device.api.util.StringProvider;

import org.appbus.bb.app.hellologging4bb.logging4bb.ILogger;
import org.appbus.bb.app.hellologging4bb.logging4bb.LoggerFactory;
import org.appbus.bb.app.hellologging4bb.logging4bb.RemoteLoggerCommand;
import org.appbus.bb.app.hellologging4bb.LocalizationResource;

/**
 * A sample application to demonstrate
 * using logging4bb via Remote Commands
 */
public final class HelloLoggingApp extends UiApplication {
	// the logger
	private static final ILogger logger = LoggerFactory.getLogger(HelloLoggingApp.class);
	
	// the theApp
	private static HelloLoggingApp theApp;
	private HelloLoggingScreen theScreen;
	
    /**
     * Entry point for application
     * @param args Command line arguments (not used)
     */
    public static void main(String[] args) {
    	logger.log("main", "starting up...");
        theApp = new HelloLoggingApp();    
        theApp.enterEventDispatcher();  
    }



    /**
     * Creates a new HelloLoggingApp object
     * and pushes the one and only screen
     * 
     */
    public HelloLoggingApp() {
    	
    	theScreen = new HelloLoggingScreen();
    	UiApplication.getUiApplication().invokeLater(new Runnable(){
    		public void run() {
    			pushScreen(theScreen);
    		}
    	});
    }
    
    /**
     * MainScreen class for the HelloLoggingScreen application 
     */
    static class HelloLoggingScreen extends MainScreen implements FieldChangeListener { 
    	
    	private static ILogger logger = LoggerFactory.getLogger(HelloLoggingScreen.class);
        
        // S C R E E N
    	private static StringProvider oneEventLabel = new StringProvider(
    			LocalizationResource.BUNDLE_NAME, LocalizationResource.BUTTONLABEL_ONE_EVENT);
    	private static StringProvider manyEventsLabel = new StringProvider(
    			LocalizationResource.BUNDLE_NAME, LocalizationResource.BUTTONLABEL_MANY_EVENTS);
    	private static StringProvider restartLoggerLabel = new StringProvider(
    			LocalizationResource.BUNDLE_NAME, LocalizationResource.BUTTONLABEL_RESTART_LOGGER);
    	private static StringProvider pauseLoggerLabel = new StringProvider(
    			LocalizationResource.BUNDLE_NAME, LocalizationResource.BUTTONLABEL_PAUSE_LOGGER);
    	private static StringProvider setLoggerPreferences2DBLabel = new StringProvider(
    			LocalizationResource.BUNDLE_NAME, LocalizationResource.BUTTONLABEL_SET_LOGGER_PREFERENCES_TO_DB);
    	private static StringProvider setLoggerPreferences2ServerLabel = new StringProvider(
    			LocalizationResource.BUNDLE_NAME, LocalizationResource.BUTTONLABEL_SET_LOGGER_PREFERENCES_TO_SERVER);
    	private static StringProvider setLoggerPreferences2DBAndServerLabel = new StringProvider(
    			LocalizationResource.BUNDLE_NAME, LocalizationResource.BUTTONLABEL_SET_LOGGER_PREFERENCES_TO_DB_AND_SERVER);
    	private static StringProvider setLoggerPreferencesStopLoggingLabel = new StringProvider(
    			LocalizationResource.BUNDLE_NAME, LocalizationResource.BUTTONLABEL_SET_LOGGER_PREFERENCES_STOP_LOGGING);
    	private static  StringProvider screenTitle = new StringProvider(
    			LocalizationResource.BUNDLE_NAME, LocalizationResource.SCREEN_TITLE);
    	
        private ButtonField logOneEventButtonField;
        private ButtonField logManyEventsButtonField; 
        private ButtonField restartLoggerButtonField;
        private ButtonField pauseLoggerButtonField;
        private ButtonField setLoggerPreferences2DBButtonField;
        private ButtonField setLoggerPreferences2ServerButtonField;
        private ButtonField setLoggerPreferences2DBAndServerButtonField;
        private ButtonField setLoggerPreferencesStopLoggingField;
        
        /**
         * Creates a new HelloLoggingScreen object
         */
        HelloLoggingScreen() {
            // Initialize screen
            setTitle(screenTitle.toString());
            
            logger.log("init", " start initializing the Hello Log One Screen");
            
            logOneEventButtonField = new ButtonField(
            		oneEventLabel.toString(),
            		ButtonField.NEVER_DIRTY | ButtonField.CONSUME_CLICK);
            logOneEventButtonField.setChangeListener(this);
            add(logOneEventButtonField);
            
            logManyEventsButtonField = new ButtonField(
            		manyEventsLabel.toString(),
            		ButtonField.NEVER_DIRTY | ButtonField.CONSUME_CLICK);
            logManyEventsButtonField.setChangeListener(this);
            add(logManyEventsButtonField);
            
            restartLoggerButtonField = new ButtonField(
            		restartLoggerLabel.toString(),
            		ButtonField.NEVER_DIRTY | ButtonField.CONSUME_CLICK);
            restartLoggerButtonField.setChangeListener(this);
            add(restartLoggerButtonField);
            
            pauseLoggerButtonField = new ButtonField(
            		pauseLoggerLabel.toString(),
            		ButtonField.NEVER_DIRTY | ButtonField.CONSUME_CLICK);
            pauseLoggerButtonField.setChangeListener(this);
            add(pauseLoggerButtonField);
            
            setLoggerPreferences2DBButtonField = new ButtonField(
            		setLoggerPreferences2DBLabel.toString(),
            		ButtonField.NEVER_DIRTY | ButtonField.CONSUME_CLICK);
            setLoggerPreferences2DBButtonField.setChangeListener(this);
            add(setLoggerPreferences2DBButtonField);
            
            setLoggerPreferences2ServerButtonField = new ButtonField(
            		setLoggerPreferences2ServerLabel.toString(),
            		ButtonField.NEVER_DIRTY | ButtonField.CONSUME_CLICK);
            setLoggerPreferences2ServerButtonField.setChangeListener(this);
            add(setLoggerPreferences2ServerButtonField);
            
            setLoggerPreferences2DBAndServerButtonField = new ButtonField(
            		setLoggerPreferences2DBAndServerLabel.toString(),
            		ButtonField.NEVER_DIRTY | ButtonField.CONSUME_CLICK);
            setLoggerPreferences2DBAndServerButtonField.setChangeListener(this);
            add(setLoggerPreferences2DBAndServerButtonField);
            
            setLoggerPreferencesStopLoggingField = new ButtonField(
            		setLoggerPreferencesStopLoggingLabel.toString(),
            		ButtonField.NEVER_DIRTY | ButtonField.CONSUME_CLICK);
            setLoggerPreferencesStopLoggingField.setChangeListener(this);
            add(setLoggerPreferencesStopLoggingField);
            
            logger.debug("init", "HelloLoggerScreen successfully initialized");
        }       
        
        /**
         * @see FieldChangeListener#fieldChanged(Field, int)
         */
        public void fieldChanged(Field field, int context) {
            if (field == logOneEventButtonField) {
				logger.log("Button to send one event was clicked");
            	return;
			}
            if (field == logManyEventsButtonField) {
				logger.log("Button to send 100 events was clicked");
				for (int i = 0; i < 100; i++) {
					logger.debug("test", "send logMessage #: "+i);
				}
            	return;
			}
            if (field == restartLoggerButtonField) {
				RemoteLoggerCommand.resumeLoggerCommandRemoteExecute();
				logger.log("Logger restarted");
            	return;
			}
            if (field == pauseLoggerButtonField) {
            	logger.log("Logger paused");
				RemoteLoggerCommand.pauseLoggerCommandRemoteExecute();
            	return;
			}
            if (field == setLoggerPreferences2DBButtonField) {
            	logger.log("begin updating Logger Preferences: DB: YES, Server: NO");
            	Hashtable columns = new Hashtable();
            	columns.put(RemoteLoggerCommand.COL_LOG_TO_DB, new Integer(1));
            	columns.put(RemoteLoggerCommand.COL_LOG_TO_LOGMONITOR, new Integer(0));
				RemoteLoggerCommand.refreshLoggerCommandRemoteExecute(columns);
            	return;
			}
            if (field == setLoggerPreferences2ServerButtonField) {
            	logger.log("begin updating Logger Preferences: DB: NO, Server: YES");
            	Hashtable columns = new Hashtable();
            	columns.put(RemoteLoggerCommand.COL_LOG_TO_DB, new Integer(0));
            	columns.put(RemoteLoggerCommand.COL_LOG_TO_LOGMONITOR, new Integer(1));
				RemoteLoggerCommand.refreshLoggerCommandRemoteExecute(columns);
            	return;
			}
            if (field == setLoggerPreferences2DBAndServerButtonField) {
            	logger.log("begin updating Logger Preferences: DB: YES, Server: YES");
            	Hashtable columns = new Hashtable();
            	columns.put(RemoteLoggerCommand.COL_LOG_TO_DB, new Integer(1));
            	columns.put(RemoteLoggerCommand.COL_LOG_TO_LOGMONITOR, new Integer(1));
				RemoteLoggerCommand.refreshLoggerCommandRemoteExecute(columns);
            	return;
			}
            if (field == setLoggerPreferencesStopLoggingField) {
            	logger.log("begin updating Logger Preferences: DB: NO, Server: YES");
            	Hashtable columns = new Hashtable();
            	columns.put(RemoteLoggerCommand.COL_LOG_TO_DB, new Integer(0));
            	columns.put(RemoteLoggerCommand.COL_LOG_TO_LOGMONITOR, new Integer(0));
				RemoteLoggerCommand.refreshLoggerCommandRemoteExecute(columns);
            	return;
			}
        }
    }
 
}
