/**
 *  Copyright (c) 2008...2012 Ekkehard Gentz (Rosenheim, Germany) and others.
 *  All rights reserved. This program and the accompanying materials
 *  are made available under the terms of the Eclipse Public License v1.0
 *  which accompanies this distribution, and is available at
 *  http://www.eclipse.org/legal/epl-v10.html
 *  
 *  Contributors:
 *          Ekkehard Gentz     - initial contribution 
 *     
 *   more info: see folder [project]/copyright
 */
package org.appbus.bb.app.hellologging4bb.logging4bb;

import net.rim.device.api.system.Characters;

/**
 * This Logger will be used if there's no logging4bb running in the back
 * All logging will be done using sysout
 * 
 * @author ekke
 *
 */
public class FallbackLogger implements ILogger {
	
	private static int defaultLogLevel = LOG_LEVEL_INFO;
	private static String appName;
	
	// its a good idea to have a separate Logger for each Class
	private Class clazz;
	
	public FallbackLogger(Class clazz) {
		this.clazz = clazz;
	}
	
	public static boolean init(
			String appName, 
			int defaultLogLevel) {
		FallbackLogger.appName = appName;
		FallbackLogger.defaultLogLevel = defaultLogLevel;
    	System.out.println("FallbackLogger initialized for App: "+appName);
        return true;
    }
	
	private void logEvent(String context, String message, int level, Throwable exception){
		if (defaultLogLevel > level) {
			return;
		}
		if (context != null && context.length() > 0) {
			message = context + Characters.COLON  + message;
		}
		System.out.println(
				logLevelTexts[level]
				+Characters.SPACE                       
				+appName
				+Characters.COLON+Characters.SPACE
				+clazz.getName()
				+Characters.COLON+Characters.SPACE
				+message);
		if (exception != null) {
			System.out.println(
					logLevelTexts[level]
	 				+Characters.SPACE                       
	 				+appName
	 				+Characters.COLON+Characters.SPACE
	 				+clazz.getName()
					+Characters.COLON+Characters.SPACE
					+"got Exception: "
					+exception.getMessage());
			exception.printStackTrace();
		}
	}

	public void debug(String logMessage) {
		logEvent(null, logMessage, LOG_LEVEL_DEBUG, null);
	}
	
	public void debug(String logMessage, Throwable exception) {
		logEvent(null, logMessage, LOG_LEVEL_DEBUG, exception);
	}

	public void debug(String context, String logMessage) {
		logEvent(context, logMessage, LOG_LEVEL_DEBUG, null);
	}

	public void debug(String context, String logMessage, Throwable exception) {
		logEvent(context, logMessage, LOG_LEVEL_DEBUG, exception);
	}
	
	public void info(String logMessage) {
		logEvent(null, logMessage, LOG_LEVEL_DEBUG, null);
	}
	
	public void info(String logMessage, Throwable exception) {
		logEvent(null, logMessage, LOG_LEVEL_DEBUG, exception);
	}

	public void info(String context, String logMessage) {
		logEvent(context, logMessage, LOG_LEVEL_DEBUG, null);
	}

	public void info(String context, String logMessage, Throwable exception) {
		logEvent(context, logMessage, LOG_LEVEL_DEBUG, exception);
	}
	
	public void log(String logMessage) {
		logEvent(null, logMessage, LOG_LEVEL_INFO, null);
	}
	
	public void log(String logMessage, Throwable exception) {
		logEvent(null, logMessage, LOG_LEVEL_INFO, exception);
	}

	public void log(String context, String logMessage) {
		logEvent(context, logMessage, LOG_LEVEL_INFO, null);
	}

	public void log(String context, String logMessage, Throwable exception) {
		logEvent(context, logMessage, LOG_LEVEL_INFO, exception);
	}
	
	public void warn(String logMessage) {
		logEvent(null, logMessage, LOG_LEVEL_WARN, null);
	}
	
	public void warn(String logMessage, Throwable exception) {
		logEvent(null, logMessage, LOG_LEVEL_WARN, exception);
	}

	public void warn(String context, String logMessage) {
		logEvent(context, logMessage, LOG_LEVEL_WARN, null);
	}

	public void warn(String context, String logMessage, Throwable exception) {
		logEvent(context, logMessage, LOG_LEVEL_WARN, exception);
	}

	public void error(String logMessage) {
		logEvent(null, logMessage, LOG_LEVEL_ERROR, null);
	}
	
	public void error(String logMessage, Throwable exception) {
		logEvent(null, logMessage, LOG_LEVEL_ERROR, exception);
	}

	public void error(String context, String logMessage) {
		logEvent(context, logMessage, LOG_LEVEL_ERROR, null);
	}

	public void error(String context, String logMessage, Throwable exception) {
		logEvent(context, logMessage, LOG_LEVEL_ERROR, exception);
	}

	public boolean isDebugEnabled() {
		return defaultLogLevel == LOG_LEVEL_DEBUG;
	}

}
